fn has_granularity_conflict(
type0: AllocationType,
type1: AllocationType,
) -> boolExpand description
Test if two allocation types will be conflicting or not.
fn has_granularity_conflict(
type0: AllocationType,
type1: AllocationType,
) -> boolTest if two allocation types will be conflicting or not.